@@ -79,11 +79,9 @@ def configure_logging():
         level = get_log_level()
         logger.info("Logging level:{}".format(level))
         logger.setLevel(level)
-        formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
+        formatter = logging.Formatter('%(asctime)s - %(name)s - [%(levelname)s] %(funcName)s(%(lineno)d) <%(process)d>: %(message)s')
         path = get_log_filename()
 
-
-
         agent_env = None
 
         if "CAV_APP_AGENT_Env" in os.environ:
