@@ -77,7 +77,7 @@ def heartbeat_sender(udp_socket, address_port, ag_obj):
             time.sleep(10)
             logger.debug("heartbeat sleep completed")
         except Exception as e:
-            logger.error("heartbeat exception", e)
+            logger.error("heartbeat exception {}".format(e))
 
 
 def incoming_message_processor(udp_socket):
@@ -135,7 +135,7 @@ def incoming_message_processor(udp_socket):
                 havoc_monitor.parse_nethavoc_config(body, header_dict)
 
             except Exception as e:
-                logger.warning("Unable to parse config: {}", e)
+                logger.warning("Unable to parse config: {}".format(e))
                 logger.warning("unable to parse message except")
 
         except socket.timeout:
