@@ -17,6 +17,7 @@ havoc_types = {
     7: "Custom_Memory_Leak"
 }
 
+
 class NDHavocException(Exception):
     def __init__(self, message):
         self.message = message
@@ -27,42 +28,47 @@ class NDNetHavocRequest(object):
     def __init__(self, havoc_conf, header_dict):
 
         self.logger = logging.getLogger('pythonagent.agent')
-
-        if hasattr(havoc_conf, 'havocType'):
-            self.havocType = havoc_conf.havocType
-
-        if hasattr(havoc_conf, 'uRL'):
-            self.uRL = havoc_conf.uRL
-
-        if hasattr(havoc_conf, 'methodFQM'):
-            self.methodFQM = havoc_conf.methodFQM
-
-        if hasattr(havoc_conf, 'delayInSec'):
-            # self.delayInSec = havoc_conf.delayInSec
-            self.delayInSec = havoc_conf.delayInSec / 1000  # UI is sending in milliseconds
-
-        if hasattr(havoc_conf, 'hostname'):
-            self.hostname = havoc_conf.hostname
-
-        #self.startTime = time.time_ns() // 1000000
         self.startTime = get_current_timestamp_in_ms()
+
         self.header_dict = header_dict
         self.nhmid = header_dict["NHMID"]
 
+        self.havocType = havoc_conf.havocType
         self.totalDurationInSec = havoc_conf.totalDurationInSec
 
+        if hasattr(havoc_conf, 'delayInSec'):
+            self.delayInSec = havoc_conf.delayInSec / 1000  # UI is sending in milliseconds
+
+        if self.havocType in [1, 2]:
+            self.bTNameMode = havoc_conf.bTNameMode
+            if hasattr(havoc_conf, 'uRL'):
+                self.uRL = havoc_conf.uRL
+
+        if self.havocType in [3, 4]:
+            self.backendNameMod = havoc_conf.backendNameMod
+            if hasattr(havoc_conf, 'hostname'):
+                self.hostname = havoc_conf.hostname
+
+        if self.havocType in [5, 6]:
+            self.methodMod = havoc_conf.methodMod
+            if hasattr(havoc_conf, 'methodFQM'):
+                self.methodFQM = havoc_conf.methodFQM
+
+        if self.havocType in [7]:
+            self.leaksINMB = havoc_conf.leaksINMB
+            self.memoryLeaksInSec = havoc_conf.memoryLeaksInSec
+
         try:
             self.enable = havoc_conf.enable
             self.bTName = havoc_conf.bTName
             self.isHavocEnable = False
             self.threshOld = havoc_conf.threshOld
             self.protocol = havoc_conf.protocol
-            self.leaksINMB = havoc_conf.leaksINMB
-            self.memoryLeaksInSec = havoc_conf.memoryLeaksInSec
             self.backendName = havoc_conf.backendName
 
         except Exception as e:
-            self.logger.warning(e)
+            self.logger.warning("Problem in creating havoc object {} ".format(e))
+
 
 
 class NDNetHavocMonitor(object):
@@ -155,40 +161,54 @@ class NDNetHavocMonitor(object):
             else:
                 self.logger.debug("threshOld validated")
 
-        # Validate uRL
+        # Validate uRL for Havoc Type 1 and 2
         if havoc_type in [1, 2]:
-            if not hasattr(havoc_conf, 'uRL'):
-                return_message = "uRL not found for inbound service"
-                return is_valid, return_message
-            else:
-                if len(havoc_conf.uRL) == 0:
-                    return_message = "invalid uRL  for inbound service"
+            self.logger.debug("bTNameMode: {}".format(havoc_conf.bTNameMode))
+            if havoc_conf.bTNameMode == 0:
+                pass
+            elif havoc_conf.bTNameMode == 3:
+                if not hasattr(havoc_conf, 'uRL'):
+                    return_message = "uRL not found for inbound service"
                     return is_valid, return_message
                 else:
-                    self.logger.debug("uRL validated")
+                    if len(havoc_conf.uRL) == 0:
+                        return_message = "invalid uRL  for inbound service"
+                        return is_valid, return_message
+                    else:
+                        self.logger.debug("uRL validated")
+            else:
+                return_message = "bTNameMode 1 and 2 not supported"
+                return is_valid, return_message
         else:
             self.logger.debug("uRL not needed")
 
-        # Validate hostname and protocol
+        # Validate hostname and protocol for Havoc Type 3 and 4
         if havoc_type in [3, 4]:
-            if not hasattr(havoc_conf, 'hostname'):
-                return_message = "hostname not found for outbound service"
-                return is_valid, return_message
-            else:
-                if len(havoc_conf.hostname) == 0:
-                    return_message = "invalid hostname for outbound service"
+            if havoc_conf.backendNameMod == 0:
+                pass
+            elif havoc_conf.backendNameMod == 3:
+                if not hasattr(havoc_conf, 'hostname'):
+                    return_message = "hostname not found for outbound service"
                     return is_valid, return_message
                 else:
-                    self.logger.debug("hostname validated")
-
-                if not hasattr(havoc_conf, 'protocol'):
-                    if havoc_conf.protocol not in ["Http", "Non Http"]:
-                        return_message = "invalid protocol for outbound service"
+                    if len(havoc_conf.hostname) == 0:
+                        return_message = "invalid hostname for outbound service"
                         return is_valid, return_message
                     else:
-                        self.logger.debug("protocol validated")
-                else:
-                    self.logger.debug("protocol not found")
+                        self.logger.debug("hostname validated")
+
+                    if not hasattr(havoc_conf, 'protocol'):
+                        if havoc_conf.protocol not in ["Http", "Non Http"]:
+                            return_message = "invalid protocol for outbound service"
+                            return is_valid, return_message
+                        else:
+                            self.logger.debug("protocol validated")
+                    else:
+                        self.logger.debug("protocol not found")
+            else:
+                return_message = "backendNameMod 1, 2, and 4 not supported"
+                return is_valid, return_message
+
         else:
             self.logger.debug("hostname not needed")
 
@@ -247,8 +267,6 @@ class NDNetHavocMonitor(object):
             self.logger.debug("header_dict: {}".format(header_dict))
             nhmid = header_dict["NHMID"]
             self.logger.debug("nhmid: {}".format(nhmid))
-
-
             self.logger.info("checking if havoc already exists")
 
             havoc_type_full_str = havoc_types[havoc_type]
@@ -266,10 +284,9 @@ class NDNetHavocMonitor(object):
             if is_valid:
                 self.logger.info(ret_message)
                 req_obj = NDNetHavocRequest(havoc_conf, header_dict)
-
+                self.logger.debug("Request Object: ".format(req_obj))
                 havoc_type_full_str = havoc_types[havoc_type]
                 self.netHavocConfigMap[havoc_type_full_str].append(req_obj)
-                # self.netHavocConfigMap[havoc_type].append(req_obj)
 
             else:
                 self.logger.info("Invalid config: {}".format(ret_message))
@@ -278,7 +295,6 @@ class NDNetHavocMonitor(object):
             self.logger.error("havoc parsing exception: {}".format(e))
             raise e
 
-
     def common_delay_in_response(self, total_duration_in_sec):
         self.logger.info("Applying delay duration(sec): {}".format(total_duration_in_sec))
         try:
@@ -313,24 +329,20 @@ class NDNetHavocMonitor(object):
             obj_created += 0
 
     def apply_inbound_service_delay(self, req_url):
-        self.logger.info("applying inbound service delay")
+        self.logger.info("Trying to apply inbound service delay")
         config_list = self.netHavocConfigMap["InBoundService_Delay"]
 
         if config_list:
             for config in config_list:
-
-                url = config.uRL
+                self.logger.debug("Trying to apply havoc: {}".format(config.nhmid))
                 delay_in_second = config.delayInSec
 
-                apply_all = False
-                if hasattr(config, 'bTNameMode'):
-                    if config.bTNameMode == 0:
-                        apply_all = True
-
-                if apply_all:
-                    self.logger.debug("bTNameMode = 0, applying")
+                if config.bTNameMode == 0:
+                    self.logger.debug("bTNameMode = 0, proceeding")
                     self.common_delay_in_response(delay_in_second)
                 else:
+                    url = config.uRL
+                    self.logger.debug("url: {} in req_url: {}".format(url, req_url))
                     if url in req_url:
                         self.logger.debug("Config matched for Request URL {}".format(req_url))
                         self.common_delay_in_response(delay_in_second)
@@ -341,52 +353,42 @@ class NDNetHavocMonitor(object):
             self.logger.debug("config not set for apply_inbound_service_delay")
 
     def apply_inbound_service_failure(self, req_url):
-        self.logger.info("applying inbound service failure")
+        self.logger.info("Trying to apply inbound service failure")
         config_list = self.netHavocConfigMap["InBoundService_Failure"]
 
         if config_list:
             for config in config_list:
-                url = config.uRL
-
-                apply_all = False
-                if hasattr(config, 'bTNameMode'):
-                    if config.bTNameMode == 0:
-                        apply_all = True
-
-                if apply_all:
-                    self.logger.debug("bTNameMode = 0, applying")
-                    self.common_failure(url)
+                self.logger.debug("Trying to apply havoc: {}".format(config.nhmid))
+                if config.bTNameMode == 0:
+                    self.logger.debug("bTNameMode = 0, proceeding")
+                    self.common_failure("BT:ALL")
                 else:
+                    url = config.uRL
+                    self.logger.debug("url: {} in req_url: {}".format(url, req_url))
                     if url in req_url:
                         self.logger.debug("Config matched for Request URL {}".format(req_url))
                         self.common_failure(url)
                     else:
                         self.logger.debug("Config not matched for Request URL {}".format(req_url))
-
-
-
         else:
             self.logger.debug("config not set for apply_inbound_service_failure")
             # raise Exception("config not set for apply_inbound_service_failure")
 
     def apply_outbound_service_delay(self, req_hostname):
-        self.logger.info("applying outbound service delay")
+        self.logger.info("Trying to apply outbound service delay")
         config_list = self.netHavocConfigMap["OutBoundService_Delay"]
 
         if config_list:
             for config in config_list:
-                hostname = config.hostname
+                self.logger.debug("Trying to apply havoc: {}".format(config.nhmid))
                 delay_in_second = config.delayInSec
-
-                apply_all = False
-                if hasattr(config, 'backendNameMod'):
-                    if config.backendNameMod == 0:
-                        apply_all = True
-
-                if apply_all:
-                    self.logger.debug("backendNameMod = 0, applying")
+                if config.backendNameMod == 0:
+                    self.logger.debug("backendNameMod = 0, proceeding")
                     self.common_delay_in_response(delay_in_second)
                 else:
+                    hostname = config.hostname
+                    self.logger.debug("hostname: {} in req_hostname: {}".format(hostname, req_hostname))
+
                     if hostname in req_hostname:
                         self.logger.debug("Config matched for Request Hostname {}".format(req_hostname))
                         self.common_delay_in_response(delay_in_second)
@@ -394,45 +396,39 @@ class NDNetHavocMonitor(object):
                         self.logger.debug("Config not matched for Request Hostname {}".format(req_hostname))
         else:
             self.logger.debug("config not set for apply_outbound_service_delay")
-            # raise Exception("config not set for apply_outbound_service_delay")
 
     def apply_outbound_service_failure(self, req_hostname):
-        self.logger.info("applying outbound service failure")
+        self.logger.info("Trying to apply outbound service failure")
         config_list = self.netHavocConfigMap["OutBoundService_Failure"]
 
         if config_list:
             for config in config_list:
-
-                hostname = config.hostname
-
-                apply_all = False
-                if hasattr(config, 'backendNameMod'):
-                    if config.backendNameMod == 0:
-                        apply_all = True
-
-                if apply_all:
-                    self.logger.debug("backendNameMod = 0, applying")
-                    self.self.common_failure(hostname)
+                self.logger.debug("Trying to apply havoc: {}".format(config.nhmid))
+                if config.backendNameMod == 0:
+                    self.logger.debug("backendNameMod = 0, proceeding")
+                    self.common_failure("Integration Point: ALL")
                 else:
+                    hostname = config.hostname
+                    self.logger.debug("hostname: {} in req_hostname: {}".format(hostname, req_hostname))
+
                     if hostname in req_hostname:
                         self.logger.debug("Config matched for Request Hostname {}".format(req_hostname))
                         self.common_failure(hostname)
                     else:
                         self.logger.debug("Config not matched for Request Hostname {}".format(req_hostname))
-
         else:
             self.logger.debug("config not set for apply_outbound_service_failure")
-            # raise Exception("config not set for apply_outbound_service_failure")
 
     def apply_method_call_delay(self, req_method_fqm):
-        self.logger.info("applying method call delay")
+        self.logger.info("Trying to apply method call delay")
         config_list = self.netHavocConfigMap["MethodCall_Delay"]
 
         if config_list:
             for config in config_list:
-
+                self.logger.debug("Trying to apply havoc: {}".format(config.nhmid))
                 delay_in_second = config.delayInSec
                 method_fqm = config.methodFQM
+                self.logger.debug("method_fqm: {} in req_method_fqm: {}".format(method_fqm, req_method_fqm))
 
                 if method_fqm in req_method_fqm:
                     self.logger.debug("Config matched for Request FQM {}".format(req_method_fqm))
@@ -441,31 +437,31 @@ class NDNetHavocMonitor(object):
                     self.logger.debug("Config not matched for Request FQM {}".format(req_method_fqm))
         else:
             self.logger.debug("config not set for apply_method_call_delay")
-            # raise Exception("config not set for apply_method_call_delay")
 
     def apply_method_invocation_failure(self, req_method_fqm):
-        self.logger.info("applying method invocation failure")
+        self.logger.info("Trying to apply method invocation failure")
         config_list = self.netHavocConfigMap["MethodCall_Failure"]
 
         if config_list:
             for config in config_list:
+                self.logger.debug("Trying to apply havoc: {}".format(config.nhmid))
                 method_fqm = config.methodFQM
+                self.logger.debug("method_fqm: {} in req_method_fqm: {}".format(method_fqm, req_method_fqm))
+
                 if method_fqm in req_method_fqm:
                     self.logger.debug("Config matched for Request FQM {}".format(req_method_fqm))
                     self.common_failure(method_fqm)
                 else:
                     self.logger.debug("Config not matched for Request FQM {}".format(req_method_fqm))
-
         else:
             self.logger.debug("config not set for apply_method_call_failure")
-            # raise Exception("config not set for apply_method_call_failure")
 
     def increase_memory_usage(self):
-        self.logger.info("applying memory leak")
+        self.logger.info("Trying to apply memory leak")
         config_list = self.netHavocConfigMap["Custom_Memory_Leak"]
         if config_list:
             for config in config_list:
-
+                self.logger.debug("Trying to apply havoc: {}".format(config.nhmid))
                 leaksINMB = config.leaksINMB
                 totalDurationInSec = config.totalDurationInSec
                 memoryLeaksInSec = config.memoryLeaksInSec
@@ -479,7 +475,6 @@ class NDNetHavocMonitor(object):
 
     def refresh_configs(self, agent_obj):
         self.logger.info("Refreshing Configs")
-        #current_time_ms = time.time_ns() // 1000000
         current_time_ms = get_current_timestamp_in_ms()
 
         for havoc_type in HAVOC_TYPES:
@@ -513,14 +508,3 @@ class NDNetHavocMonitor(object):
                         self.logger.debug("Config {} for type {} not expired, continuing".format(id(config), config.havocType))
             else:
                 self.logger.debug("config not found for havoc type {}".format(havoc_type))
-
-
-if __name__ == '__main__':
-
-    # json_path = "havocprofile1.json"
-    havoc_monitor = NDNetHavocMonitor()
-    havoc_monitor.parse_nethavoc_config(HAVOC_PROFILES_JSON[0], HAVOC_TYPES[0])
-    havoc_monitor.parse_nethavoc_config(HAVOC_PROFILES_JSON[1], HAVOC_TYPES[1])
-    havoc_monitor.apply_inbound_service_delay("sample_url")
-    havoc_monitor.apply_inbound_service_failure("sample_url")
-    havoc_monitor.refresh_configs()
