@@ -3,7 +3,6 @@
 """
 
 from __future__ import unicode_literals
-import logging
 import os
 import sys
 
@@ -14,12 +13,9 @@ except ValueError:  # directory not in sys.path
 
 try:
     import pythonagent.agent as agent
-    #agent.Agent.start()
     agent.configure()
     agent.bootstrap()
-except:
-    logger = logging.getLogger('pythonagent.agent')
-    logger.exception('Exception in agent startup.')
-finally: 
+except Exception as e:
+    print('Exception in agent startup.', e)
+finally:
     pass
-    #appdynamics.agent.load_sitecustomize()
